## Flow

You can create a simple app with the following code:

```Python 
from tensorpc.flow import mui, three, plus, appctx, mark_create_layout, flow
class App:
    
    class Config(plus.AppInMemory.Config):
        is_horizontal = False
        height = "800px"

    @mark_create_layout
    def my_layout(self):
        nodes = [
            flow.Node(id="1-1", type="input", data=flow.NodeData(label="Input Node"), position=flow.XYPosition(150, 0)),
            flow.Node(id="1-2", type="default", data=flow.NodeData(label="Default Node"), position=flow.XYPosition(0, 100)),
            flow.Node(id="1-3", type="output", data=flow.NodeData(label="Output Node"), position=flow.XYPosition(300, 100)),
            flow.Node(id="2-1", type="group", position=flow.XYPosition(-170, 250), style={
                "width": 380,
                "height": 180,
                "backgroundColor": 'rgba(208, 192, 247, 0.2)',
            }),
            flow.Node(id="2-2", type="app", data=flow.NodeData(component=mui.Fragment([
                flow.NodeToolbar([
                    mui.Markdown("🚀🔥✨"),
                ]).prop(isVisible=True),
                flow.Handle(type="target", position="left"),
                flow.Handle(type="source", position="right"),
                mui.Typography("🚀"),
            ])), position=flow.XYPosition(50, 50), style={
                "width": 80,
                "height": 80,
                "backgroundColor": 'rgba(208, 192, 247)',
            }, parentId="2-1", extent="parent"),
            flow.Node(id="2-3", type="app", data=flow.NodeData(component=mui.Fragment([
                flow.NodeResizer().prop(minWidth=50, minHeight=50),
                flow.Handle(type="target", position="left"),
                mui.Typography("resizable node").prop(variant="caption"),
                mui.HBox([
                    flow.Handle(type="source", position="bottom").prop(style={"position": 'relative', "left": 0, "transform": 'none' }, id="a"),
                    flow.Handle(type="source", position="bottom").prop(style={"position": 'relative', "left": 0, "transform": 'none' }, id="b"),
                ]).prop(justifyContent="space-evenly", width="100%", bottom=0, position="absolute"),

            ])), position=flow.XYPosition(250, 50), style={
                "width": 80,
                "height": 80,
                "backgroundColor": 'rgba(208, 192, 247)',
            }, parentId="2-1", extent="parent"),
        ]
        edges = [
            flow.Edge("e1-2", source="1-1", target="1-2", label="edge", type="smoothstep"),
            flow.Edge("e1-3", source="1-1", target="1-3", label="animated edge", animated=True),
            flow.Edge("e2-2", source="1-2", target="2-2", type="smoothstep", markerEnd=flow.EdgeMarker(type="arrowclosed")),
            flow.Edge("e2-3", source="2-2", target="2-3", type="smoothstep", markerEnd=flow.EdgeMarker(type="arrowclosed")),
        ]
        return mui.HBox([
            flow.Flow(nodes, edges, [
                flow.MiniMap(),
                flow.Controls(),
                flow.Background()
            ])
        ]).prop(width="100%", height="100%", overflow="hidden")
```

